@@ -19,7 +19,7 @@ from collections import namedtuple, defaultdict
 import re
 from loguru import logger
 from itertools import dropwhile, takewhile
-from .loader import makedir
+from .loader import makedir, os
 
 device = 'cuda' if torch.cuda.is_available() else 'cpu'
 
